diff --git a/src/backend/access/transam/multixact.c b/src/backend/access/transam/multixact.c
--- a/src/backend/access/transam/multixact.c
+++ b/src/backend/access/transam/multixact.c
@@ -3342,7 +3342,7 @@ pg_get_multixact_members(PG_FUNCTION_ARG
 	} mxact;
 	MultiXactId mxid = PG_GETARG_UINT32(0);
 	mxact	   *multi;
-	FuncCallContext *funccxt;
+	FuncCallContext *funcctx;
 
 	if (mxid < FirstMultiXactId)
 		ereport(ERROR,
@@ -3354,8 +3354,8 @@ pg_get_multixact_members(PG_FUNCTION_ARG
 		MemoryContext oldcxt;
 		TupleDesc	tupdesc;
 
-		funccxt = SRF_FIRSTCALL_INIT();
-		oldcxt = MemoryContextSwitchTo(funccxt->multi_call_memory_ctx);
+		funcctx = SRF_FIRSTCALL_INIT();
+		oldcxt = MemoryContextSwitchTo(funcctx->multi_call_memory_ctx);
 
 		multi = palloc(sizeof(mxact));
 		/* no need to allow for old values here */
@@ -3369,14 +3369,14 @@ pg_get_multixact_members(PG_FUNCTION_ARG
 		TupleDescInitEntry(tupdesc, (AttrNumber) 2, "mode",
 						   TEXTOID, -1, 0);
 
-		funccxt->attinmeta = TupleDescGetAttInMetadata(tupdesc);
-		funccxt->user_fctx = multi;
+		funcctx->attinmeta = TupleDescGetAttInMetadata(tupdesc);
+		funcctx->user_fctx = multi;
 
 		MemoryContextSwitchTo(oldcxt);
 	}
 
-	funccxt = SRF_PERCALL_SETUP();
-	multi = (mxact *) funccxt->user_fctx;
+	funcctx = SRF_PERCALL_SETUP();
+	multi = (mxact *) funcctx->user_fctx;
 
 	while (multi->iter < multi->nmembers)
 	{
@@ -3386,16 +3386,16 @@ pg_get_multixact_members(PG_FUNCTION_ARG
 		values[0] = psprintf("%u", multi->members[multi->iter].xid);
 		values[1] = mxstatus_to_string(multi->members[multi->iter].status);
 
-		tuple = BuildTupleFromCStrings(funccxt->attinmeta, values);
+		tuple = BuildTupleFromCStrings(funcctx->attinmeta, values);
 
 		multi->iter++;
 		pfree(values[0]);
-		SRF_RETURN_NEXT(funccxt, HeapTupleGetDatum(tuple));
+		SRF_RETURN_NEXT(funcctx, HeapTupleGetDatum(tuple));
 	}
 
 	if (multi->nmembers > 0)
 		pfree(multi->members);
 	pfree(multi);
 
-	SRF_RETURN_DONE(funccxt);
+	SRF_RETURN_DONE(funcctx);
 }
diff --git a/src/backend/access/transam/xlog.c b/src/backend/access/transam/xlog.c
--- a/src/backend/access/transam/xlog.c
+++ b/src/backend/access/transam/xlog.c
@@ -851,7 +851,7 @@ static bool InstallXLogFileSegment(XLogS
 					   bool find_free, XLogSegNo max_segno,
 					   bool use_lock);
 static int XLogFileRead(XLogSegNo segno, int emode, TimeLineID tli,
-			 int source, bool notexistOk);
+			 int source, bool notfoundOk);
 static int	XLogFileReadAnyTLI(XLogSegNo segno, int emode, int source);
 static int XLogPageRead(XLogReaderState *xlogreader, XLogRecPtr targetPagePtr,
 			 int reqLen, XLogRecPtr targetRecPtr, char *readBuf,
diff --git a/src/backend/executor/nodeAgg.c b/src/backend/executor/nodeAgg.c
--- a/src/backend/executor/nodeAgg.c
+++ b/src/backend/executor/nodeAgg.c
@@ -486,7 +486,7 @@ static void agg_fill_hash_table(AggState
 static TupleTableSlot *agg_retrieve_hash_table(AggState *aggstate);
 static Datum GetAggInitVal(Datum textInitVal, Oid transtype);
 static void build_pertrans_for_aggref(AggStatePerTrans pertrans,
-						  AggState *aggsate, EState *estate,
+						  AggState *aggstate, EState *estate,
 						  Aggref *aggref, Oid aggtransfn, Oid aggtranstype,
 						  Oid aggserialfn, Oid aggdeserialfn,
 						  Datum initValue, bool initValueIsNull,
diff --git a/src/backend/replication/walreceiverfuncs.c b/src/backend/replication/walreceiverfuncs.c
--- a/src/backend/replication/walreceiverfuncs.c
+++ b/src/backend/replication/walreceiverfuncs.c
@@ -322,7 +322,7 @@ GetReplicationApplyDelay(void)
 	long		secs;
 	int			usecs;
 
-	TimestampTz chunckReplayStartTime;
+	TimestampTz chunkReplayStartTime;
 
 	SpinLockAcquire(&walrcv->mutex);
 	receivePtr = walrcv->receivedUpto;
@@ -333,12 +333,12 @@ GetReplicationApplyDelay(void)
 	if (receivePtr == replayPtr)
 		return 0;
 
-	chunckReplayStartTime = GetCurrentChunkReplayStartTime();
+	chunkReplayStartTime = GetCurrentChunkReplayStartTime();
 
-	if (chunckReplayStartTime == 0)
+	if (chunkReplayStartTime == 0)
 		return -1;
 
-	TimestampDifference(chunckReplayStartTime,
+	TimestampDifference(chunkReplayStartTime,
 						GetCurrentTimestamp(),
 						&secs, &usecs);
 
diff --git a/src/backend/tsearch/dict_thesaurus.c b/src/backend/tsearch/dict_thesaurus.c
--- a/src/backend/tsearch/dict_thesaurus.c
+++ b/src/backend/tsearch/dict_thesaurus.c
@@ -183,7 +183,7 @@ thesaurusRead(char *filename, DictThesau
 	{
 		char	   *ptr;
 		int			state = TR_WAITLEX;
-		char	   *beginwrd = NULL;
+		char	   *beginword = NULL;
 		uint32		posinsubst = 0;
 		uint32		nwrd = 0;
 
@@ -214,7 +214,7 @@ thesaurusRead(char *filename, DictThesau
 				}
 				else if (!t_isspace(ptr))
 				{
-					beginwrd = ptr;
+					beginword = ptr;
 					state = TR_INLEX;
 				}
 			}
@@ -222,12 +222,12 @@ thesaurusRead(char *filename, DictThesau
 			{
 				if (t_iseq(ptr, ':'))
 				{
-					newLexeme(d, beginwrd, ptr, idsubst, posinsubst++);
+					newLexeme(d, beginword, ptr, idsubst, posinsubst++);
 					state = TR_WAITSUBS;
 				}
 				else if (t_isspace(ptr))
 				{
-					newLexeme(d, beginwrd, ptr, idsubst, posinsubst++);
+					newLexeme(d, beginword, ptr, idsubst, posinsubst++);
 					state = TR_WAITLEX;
 				}
 			}
@@ -237,18 +237,18 @@ thesaurusRead(char *filename, DictThesau
 				{
 					useasis = true;
 					state = TR_INSUBS;
-					beginwrd = ptr + pg_mblen(ptr);
+					beginword = ptr + pg_mblen(ptr);
 				}
 				else if (t_iseq(ptr, '\\'))
 				{
 					useasis = false;
 					state = TR_INSUBS;
-					beginwrd = ptr + pg_mblen(ptr);
+					beginword = ptr + pg_mblen(ptr);
 				}
 				else if (!t_isspace(ptr))
 				{
 					useasis = false;
-					beginwrd = ptr;
+					beginword = ptr;
 					state = TR_INSUBS;
 				}
 			}
@@ -256,11 +256,11 @@ thesaurusRead(char *filename, DictThesau
 			{
 				if (t_isspace(ptr))
 				{
-					if (ptr == beginwrd)
+					if (ptr == beginword)
 						ereport(ERROR,
 								(errcode(ERRCODE_CONFIG_FILE_ERROR),
 								 errmsg("unexpected end of line or lexeme")));
-					addWrd(d, beginwrd, ptr, idsubst, nwrd++, posinsubst, useasis);
+					addWrd(d, beginword, ptr, idsubst, nwrd++, posinsubst, useasis);
 					state = TR_WAITSUBS;
 				}
 			}
@@ -272,11 +272,11 @@ thesaurusRead(char *filename, DictThesau
 
 		if (state == TR_INSUBS)
 		{
-			if (ptr == beginwrd)
+			if (ptr == beginword)
 				ereport(ERROR,
 						(errcode(ERRCODE_CONFIG_FILE_ERROR),
 						 errmsg("unexpected end of line or lexeme")));
-			addWrd(d, beginwrd, ptr, idsubst, nwrd++, posinsubst, useasis);
+			addWrd(d, beginword, ptr, idsubst, nwrd++, posinsubst, useasis);
 		}
 
 		idsubst++;
diff --git a/src/include/access/xlog_internal.h b/src/include/access/xlog_internal.h
--- a/src/include/access/xlog_internal.h
+++ b/src/include/access/xlog_internal.h
@@ -284,7 +284,7 @@ extern const RmgrData RmgrTable[];
  * Exported to support xlog switching from checkpointer
  */
 extern pg_time_t GetLastSegSwitchData(XLogRecPtr *lastSwitchLSN);
-extern XLogRecPtr RequestXLogSwitch(bool mark_uninmportant);
+extern XLogRecPtr RequestXLogSwitch(bool mark_unimportant);
 
 extern void GetOldestRestartPoint(XLogRecPtr *oldrecptr, TimeLineID *oldtli);
 
diff --git a/src/interfaces/ecpg/preproc/type.c b/src/interfaces/ecpg/preproc/type.c
--- a/src/interfaces/ecpg/preproc/type.c
+++ b/src/interfaces/ecpg/preproc/type.c
@@ -231,8 +231,8 @@ get_type(enum ECPGttype type)
  */
 static void ECPGdump_a_simple(FILE *o, const char *name, enum ECPGttype type,
 				  char *varcharsize,
-				  char *arrsiz, const char *siz, const char *prefix, int);
-static void ECPGdump_a_struct(FILE *o, const char *name, const char *ind_name, char *arrsiz,
+				  char *arrsize, const char *siz, const char *prefix, int);
+static void ECPGdump_a_struct(FILE *o, const char *name, const char *ind_name, char *arrsize,
 				  struct ECPGtype * type, struct ECPGtype * ind_type, const char *prefix, const char *ind_prefix);
 
 void
@@ -569,7 +569,7 @@ ECPGdump_a_simple(FILE *o, const char *n
 
 /* Penetrate a struct and dump the contents. */
 static void
-ECPGdump_a_struct(FILE *o, const char *name, const char *ind_name, char *arrsiz, struct ECPGtype * type, struct ECPGtype * ind_type, const char *prefix, const char *ind_prefix)
+ECPGdump_a_struct(FILE *o, const char *name, const char *ind_name, char *arrsize, struct ECPGtype * type, struct ECPGtype * ind_type, const char *prefix, const char *ind_prefix)
 {
 	/*
 	 * If offset is NULL, then this is the first recursive level. If not then
@@ -580,7 +580,7 @@ ECPGdump_a_struct(FILE *o, const char *n
 	char	   *pbuf = (char *) mm_alloc(strlen(name) + ((prefix == NULL) ? 0 : strlen(prefix)) + 3);
 	char	   *ind_pbuf = (char *) mm_alloc(strlen(ind_name) + ((ind_prefix == NULL) ? 0 : strlen(ind_prefix)) + 3);
 
-	if (atoi(arrsiz) == 1)
+	if (atoi(arrsize) == 1)
 		sprintf(pbuf, "%s%s.", prefix ? prefix : "", name);
 	else
 		sprintf(pbuf, "%s%s->", prefix ? prefix : "", name);
@@ -591,7 +591,7 @@ ECPGdump_a_struct(FILE *o, const char *n
 		ind_p = &struct_no_indicator;
 	else if (ind_type != NULL)
 	{
-		if (atoi(arrsiz) == 1)
+		if (atoi(arrsize) == 1)
 			sprintf(ind_pbuf, "%s%s.", ind_prefix ? ind_prefix : "", ind_name);
 		else
 			sprintf(ind_pbuf, "%s%s->", ind_prefix ? ind_prefix : "", ind_name);
@@ -606,7 +606,7 @@ ECPGdump_a_struct(FILE *o, const char *n
 						(ind_p != NULL) ? ind_p->name : NULL,
 						(ind_p != NULL) ? ind_p->type : NULL,
 						-1,
-						prefix, ind_prefix, arrsiz, type->struct_sizeof,
+						prefix, ind_prefix, arrsize, type->struct_sizeof,
 						(ind_p != NULL) ? ind_type->struct_sizeof : NULL);
 		if (ind_p != NULL && ind_p != &struct_no_indicator)
 			ind_p = ind_p->next;
